@@ -25,13 +25,11 @@
 #include "kget_debug.h"
 #include <KIconLoader>
 #include <KIO/DeleteJob>
-#include <KIO/NetAccess>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KDialog>
-#include <KStandardDirs>
 
+#include <QDialog>
 #include <QFile>
 #include <QDomElement>
 
@@ -480,7 +478,7 @@ void AbstractMetalink::filesSelected()
                     doDownload = false;
                 //ask the user, unless he has chosen overwriteAll before
                 } else if (!overwriteAll) {
-                    KIO::RenameDialog dlg(0, i18n("File already exists"), index.data().toString(), dest, KIO::RenameDialog_Mode(KIO::M_MULTI | KIO::M_OVERWRITE | KIO::M_SKIP));
+                    KIO::RenameDialog dlg(0, i18n("File already exists"), index.data().toString(), dest, KIO::RenameDialog_Options(KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Overwrite | KIO::RenameDialog_Skip));
                     const int result = dlg.exec();
 
                     if (result == KIO::R_RENAME) {
